;; Generated package description from websocket.el  -*- no-byte-compile: t -*-
(define-package "websocket" "1.14" "Emacs WebSocket client and server" '((cl-lib "0.5")) :commit "1f086f14f0f55f55eafd09f404f48e924157c1d1" :authors '(("Andrew Hyatt" . "ahyatt@gmail.com")) :maintainer '("Andrew Hyatt" . "ahyatt@gmail.com") :keywords '("communication" "websocket" "server") :url "https://github.com/ahyatt/emacs-websocket")
